
.. _strings:

Mac OSX strings
***************

.. versionadded:: 1.8

Mac OSX .strings files are used for some Cocoa / Carbon application
localization, such as for the iPhone, iPod, and OSX. They are somewhat similar
to Java properties, and therefore :doc:`prop2po </commands/prop2po>` and
po2prop are used for conversion.

.. _strings#references:

References
==========

* `Localising string resources
  <https://developer.apple.com/library/mac/#documentation/MacOSX/Conceptual/BPInternational/Articles/StringsFiles.html#//apple_ref/doc/uid/20000005-SW1>`_
* `Manual creation of .strings files
  <https://developer.apple.com/library/mac/#documentation/Cocoa/Conceptual/LoadingResources/Strings/Strings.html#//apple_ref/doc/uid/10000051i-CH6-SW10>`_
* `String format specifiers
  <https://developer.apple.com/library/mac/#documentation/Cocoa/Conceptual/Strings/Articles/formatSpecifiers.html>`_
